@@ -4,7 +4,7 @@
 #include "modules/packages/packages.h"
 #include "util/stringUtils.h"
 
-#define FF_PACKAGES_NUM_FORMAT_ARGS 30
+#define FF_PACKAGES_NUM_FORMAT_ARGS 32
 
 void ffPrintPackages(FFPackagesOptions* options)
 {
@@ -66,6 +66,8 @@ void ffPrintPackages(FFPackagesOptions* options)
         FF_PRINT_PACKAGE(opkg)
         FF_PRINT_PACKAGE(am)
         FF_PRINT_PACKAGE(sorcery)
+        FF_PRINT_PACKAGE(lpkg)
+        FF_PRINT_PACKAGE(lpkgbuild)
 
         putchar('\n');
     }
@@ -102,6 +104,8 @@ void ffPrintPackages(FFPackagesOptions* options)
             {FF_FORMAT_ARG_TYPE_UINT, &counts.opkg},
             {FF_FORMAT_ARG_TYPE_UINT, &counts.am},
             {FF_FORMAT_ARG_TYPE_UINT, &counts.sorcery},
+            {FF_FORMAT_ARG_TYPE_UINT, &counts.lpkg},
+            {FF_FORMAT_ARG_TYPE_UINT, &counts.lpkgbuild},
             {FF_FORMAT_ARG_TYPE_UINT, &nixAll},
             {FF_FORMAT_ARG_TYPE_UINT, &flatpakAll},
             {FF_FORMAT_ARG_TYPE_UINT, &brewAll},
@@ -153,6 +157,10 @@ bool ffParsePackagesCommandOptions(FFPackagesOptions* options, const char* key,
                 case 'F': if (false);
                     FF_TEST_PACKAGE_NAME(FLATPAK)
                     break;
+                case 'L': if (false);
+                    FF_TEST_PACKAGE_NAME(LPKG)
+                    FF_TEST_PACKAGE_NAME(LPKGBUILD)
+                    break;
                 case 'M': if (false);
                     FF_TEST_PACKAGE_NAME(MACPORTS)
                     break;
@@ -254,6 +262,10 @@ void ffParsePackagesJsonObject(FFPackagesOptions* options, yyjson_val* module)
                         case 'F': if (false);
                             FF_TEST_PACKAGE_NAME(FLATPAK)
                             break;
+                        case 'L': if (false);
+                            FF_TEST_PACKAGE_NAME(LPKG)
+                            FF_TEST_PACKAGE_NAME(LPKGBUILD)
+                            break;
                         case 'M': if (false);
                             FF_TEST_PACKAGE_NAME(MACPORTS)
                             break;
@@ -313,6 +325,8 @@ void ffGeneratePackagesJsonConfig(FFPackagesOptions* options, yyjson_mut_doc* do
         FF_TEST_PACKAGE_NAME(EMERGE)
         FF_TEST_PACKAGE_NAME(EOPKG)
         FF_TEST_PACKAGE_NAME(FLATPAK)
+        FF_TEST_PACKAGE_NAME(LPKG)
+        FF_TEST_PACKAGE_NAME(LPKGBUILD)
         FF_TEST_PACKAGE_NAME(NIX)
         FF_TEST_PACKAGE_NAME(OPKG)
         FF_TEST_PACKAGE_NAME(PACMAN)
@@ -379,7 +393,7 @@ void ffGeneratePackagesJsonResult(FF_MAYBE_UNUSED FFPackagesOptions* options, yy
 
 void ffPrintPackagesHelpFormat(void)
 {
-    FF_PRINT_MODULE_FORMAT_HELP_CHECKED(FF_PACKAGES_MODULE_NAME, "{2} (pacman){?3}[{3}]{?}, {4} (dpkg), {5} (rpm), {6} (emerge), {7} (eopkg), {8} (xbps), {9} (nix-system), {10} (nix-user), {11} (nix-default), {12} (apk), {13} (pkg), {14} (flatpak-system), {15} (flatpack-user), {16} (snap), {17} (brew), {18} (brew-cask), {19} (MacPorts), {20} (scoop), {21} (choco), {22} (pkgtool), {23} (paludis), {24} (winget), {25} (opkg), {26} (am), {27} (sorcery)", FF_PACKAGES_NUM_FORMAT_ARGS, ((const char* []) {
+    FF_PRINT_MODULE_FORMAT_HELP_CHECKED(FF_PACKAGES_MODULE_NAME, "{2} (pacman){?3}[{3}]{?}, {4} (dpkg), {5} (rpm), {6} (emerge), {7} (eopkg), {8} (xbps), {9} (nix-system), {10} (nix-user), {11} (nix-default), {12} (apk), {13} (pkg), {14} (flatpak-system), {15} (flatpack-user), {16} (snap), {17} (brew), {18} (brew-cask), {19} (MacPorts), {20} (scoop), {21} (choco), {22} (pkgtool), {23} (paludis), {24} (winget), {25} (opkg), {26} (am), {27} (sorcery), {28} (lpkg), {29} (lpkgbuild)", FF_PACKAGES_NUM_FORMAT_ARGS, ((const char* []) {
         "Number of all packages",
         "Number of pacman packages",
         "Pacman branch on manjaro",
@@ -407,6 +421,8 @@ void ffPrintPackagesHelpFormat(void)
         "Number of opkg packages",
         "Number of am packages",
         "Number of sorcery packages",
+        "Number of lpkg packages",
+        "Number of lpkgbuild packages",
         "Total number of all nix packages",
         "Total number of all flatpak packages",
         "Total number of all brew packages",
